@@ -100,7 +100,7 @@ contrast = function(object, ...)
 #' @return \code{contrast} and \code{pairs} return an object of class
 #'   \code{emmGrid}. Its grid will correspond to the levels of the contrasts and
 #'   any \code{by} variables. The exception is that an \code{\link{emm_list}}
-#'   object is returned if \code{simple} is a list and \code{complete} is
+#'   object is returned if \code{simple} is a list and \code{combine} is
 #'   \code{FALSE}.
 #'
 #' @section Pairs method: The call \code{pairs(object)} is equivalent to
@@ -155,10 +155,13 @@ contrast = function(object, ...)
 #'
 #' @examples
 #' warp.lm <- lm(breaks ~ wool*tension, data = warpbreaks)
-#' warp.emm <- emmeans(warp.lm, ~ tension | wool)
+#' (warp.emm <- emmeans(warp.lm, ~ tension | wool))
 #' 
 #' contrast(warp.emm, "poly")    # inherits 'by = "wool"' from warp.emm
 #' 
+#' ### Custom contrast coefs (we already have wool as 'by' thus 3 means to contrast)
+#' contrast(warp.emm, list(mid.vs.ends = c(-1,2,-1)/2, lo.vs.hi = c(1,0,-1)))
+#' 
 #' pairs(warp.emm)
 #' 
 #' # Effects (dev from mean) of the 6 factor combs, with enhanced levels:
@@ -481,7 +484,7 @@ contrast.emmGrid = function(object, method = "eff", interaction = FALSE,
         else {
             misc$initMesg = c(misc$initMesg, 
                               paste("Note: contrasts are still on the", misc$orig.tran, "scale"))
-            message("Note: Use 'contrast(regrid(object), ...)' to obtain contrasts of back-transformed estimates")
+            ### message("Note: Use 'contrast(regrid(object), ...)' to obtain contrasts of back-transformed estimates")
             misc$tran = misc$tran.mult = misc$tran.offset = NULL
         }
     }
@@ -510,7 +513,7 @@ contrast.emmGrid = function(object, method = "eff", interaction = FALSE,
 # e.g., with factors A, B, C, simple = "A" <==> by = c("B", "C")
 # Note `by` is an argument so that it can be ignored and never duplicated
 # If `simple` is a list, we run this on each element
-# If simple = "each", we run it on each factorin the grid
+# If simple = "each", we run it on each factor in the grid
 # We handle `adjust`` ourselves rather than passing it to `contrast``
 .simcon = function(object, ..., simple, by, combine = FALSE, adjust) {
     if (is.list(simple)) {
