@@ -30,8 +30,12 @@
 #' effect sizes -- unrealistically if in fact \code{sigma} is unknown.
 #' 
 #'
-#' @param object an \code{\link[=emmGrid-class]{emmGrid}} object, typically one defining the EMMs to 
-#' be contrasted.
+#' @param object an \code{\link[=emmGrid-class]{emmGrid}} object, 
+#' typically one defining the EMMs to 
+#' be contrasted. If instead, \code{class(object) == "emm_list"},
+#' such as is produced by \code{emmeans(model, pairwise ~ treatment)},
+#' a message is displayed; the contrasts already therein are used; and 
+#' \code{method} is replaced by \code{"identity"}.
 #' @param sigma numeric scalar, value of the population SD. 
 #' @param edf numeric scalar that specifies the equivalent degrees of freedom
 #'   for the \code{sigma}. This is a way of specifying the uncertainty in \code{sigma},
@@ -65,6 +69,11 @@
 #' back-transformation changes the SD required to compute effect sizes. 
 #' 
 #' @note
+#' \strong{Paired data:} Be careful with paired-data situations, where Cohen's d is typically referenced to
+#' the SD of the \emph{paired differences} rather than the \emph{residual} SD.
+#' You may need to enlarge \code{sigma} by a factor of \code{sqrt(2)} to obtain
+#' comparable results with other software.
+#' @note
 #' \strong{Disclaimer:} There is substantial disagreement among practitioners on
 #' what is the appropriate \code{sigma} to use in computing effect sizes; or,
 #' indeed, whether \emph{any} effect-size measure is appropriate for some
@@ -72,6 +81,8 @@
 #' appropriate parameters (or for failing to do so).
 #' 
 #' @export
+#' @note 
+#' The examples here illustrate a sobering message that effect sizes are often not nearly as accurate as you may think.
 #'
 #' @examples
 #' fiber.lm <- lm(strength ~ diameter + machine, data = fiber)
@@ -84,31 +95,30 @@
 #' 
 #' 
 #' ### Mixed model example:
-#' if (require(nlme)) {
-#' 
+#' if (require(nlme)) withAutoprint({
 #'   Oats.lme <- lme(yield ~ Variety + factor(nitro), 
 #'                   random = ~ 1 | Block / Variety,
 #'                   data = Oats)
-#'                   
 #'   # Combine variance estimates
 #'   VarCorr(Oats.lme)
-#'   totSD <- sqrt(214.4724 + 109.6931 + 162.5590)
+#'   (totSD <- sqrt(214.4724 + 109.6931 + 162.5590))
 #'   # I figure edf is somewhere between 5 (Blocks df) and 51 (Resid df)
-#'   
 #'   emmV <- emmeans(Oats.lme, ~ Variety)
-#'   print(eff_size(emmV, sigma = totSD, edf = 5))
-#'   print(eff_size(emmV, sigma = totSD, edf = 51))
-#' }
+#'   eff_size(emmV, sigma = totSD, edf = 5)
+#'   eff_size(emmV, sigma = totSD, edf = 51)
+#' }, spaced = TRUE)
 #' 
 #' # Multivariate model for the same data:
 #'  MOats.lm <- lm(yield ~ Variety, data = MOats)
 #'  eff_size(emmeans(MOats.lm, "Variety"), 
 #'           sigma = sqrt(mean(sigma(MOats.lm)^2)),   # RMS of sigma()
 #'           edf = df.residual(MOats.lm))
-#' 
-#' # These results illustrate a sobering message that effect sizes are often
-#' # not nearly as accurate as you may think.
 eff_size = function(object, sigma, edf, method = "pairwise", ...) {
+    if (inherits(object, "emm_list") && ("contrasts" %in% names(object))) {
+        message("Since 'object' is a list, we are using the contrasts already present.")
+        object = object$contrasts
+        method = "identity"
+    }
     SE.logsigma = sqrt(1 / (2 * edf))
  
     object = update(object, tran = NULL)
