@@ -185,16 +185,21 @@ recover_data.call = function(object, trms, na.action, data = NULL,
                              params = "pi", frame, pwts, addl.vars, ...) {
     fcall = object # because I'm easily confused
     vars = setdiff(.all.vars(trms), params)
+    offarg = fcall$offset
     if(missing(addl.vars))
         addl.vars = character(0)
     vars = union(vars, addl.vars)
         
-    .offset. = NULL
     if (!missing(frame)) {
-        .offset. = model.offset(frame)
         if(is.null(data) && !.has.fcns(trms))
             data = frame
+        if("(offset)" %in% names(data)) 
+            vars = union(vars, "(offset)")
     }
+    else if(!is.null(offarg))
+        vars = union(vars, .all.vars(reformulate(deparse(offarg))))
+    
+    
     tbl = data
     if (length(vars) == 0 || vars[1] == "1") {
         tbl = data.frame(c(1,1))
@@ -256,6 +261,20 @@ recover_data.call = function(object, trms, na.action, data = NULL,
         tbl = tbl[, vars, drop = FALSE] # consider only the variables actually needed
         tbl = tbl[complete.cases(tbl), , drop=FALSE]
     }
+    # if there is a separate offset argument, calculate the static offset
+    if(!is.null(offarg)) {
+        if ("(offset)" %in% names(tbl)) { # don't have to calculate it
+            offval = tbl[["(offset)"]]
+            vars = setdiff(vars, "(offset)")
+        }
+        else
+            offval = eval(offarg, tbl, enclos = environment(trms))
+        if(!is.null(offval)) {
+            tbl$.static.offset. = offval
+            addl.vars = c(addl.vars, ".static.offset.")
+        }
+    }
+
     
     if(!missing(pwts) && !is.null(pwts)) {
         if (length(pwts) == nrow(tbl))
@@ -266,11 +285,6 @@ recover_data.call = function(object, trms, na.action, data = NULL,
                     call. = FALSE)
     }
     
-    if(!is.null(.offset.) && !all(.offset. == 0)) {
-        tbl[[".offset."]] = .offset.
-        addl.vars = c(addl.vars, ".offset.")
-    }
-    
     attr(tbl, "call") = object # the original call
     attr(tbl, "terms") = trms
     attr(tbl, "predictors") = setdiff(.all.vars(delete.response(trms)), params)
